==> xunit-0.4-sources.jar: com/thalesgroup/hudson/plugins/xunit/types/Messages.java <==
// CHECKSTYLE:OFF

package com.thalesgroup.hudson.plugins.xunit.types;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * PHPUnit
     * 
     */
    public static String xUnit_phpunitType_label() {
        return holder.format("xUnit.phpunitType.label");
    }

    /**
     * PHPUnit
     * 
     */
    public static Localizable _xUnit_phpunitType_label() {
        return new Localizable(holder, "xUnit.phpunitType.label");
    }

    /**
     * NUnit
     * 
     */
    public static String xUnit_nunitType_label() {
        return holder.format("xUnit.nunitType.label");
    }

    /**
     * NUnit
     * 
     */
    public static Localizable _xUnit_nunitType_label() {
        return new Localizable(holder, "xUnit.nunitType.label");
    }

    /**
     * MSTest
     * 
     */
    public static String xUnit_mstestType_label() {
        return holder.format("xUnit.mstestType.label");
    }

    /**
     * MSTest
     * 
     */
    public static Localizable _xUnit_mstestType_label() {
        return new Localizable(holder, "xUnit.mstestType.label");
    }

    /**
     * Gallio
     * 
     */
    public static String xUnit_gallioType_label() {
        return holder.format("xUnit.gallioType.label");
    }

    /**
     * Gallio
     * 
     */
    public static Localizable _xUnit_gallioType_label() {
        return new Localizable(holder, "xUnit.gallioType.label");
    }

    /**
     * CppUnit
     * 
     */
    public static String xUnit_cppUnitType_label() {
        return holder.format("xUnit.cppUnitType.label");
    }

    /**
     * CppUnit
     * 
     */
    public static Localizable _xUnit_cppUnitType_label() {
        return new Localizable(holder, "xUnit.cppUnitType.label");
    }

    /**
     * Custom Tool
     * 
     */
    public static String xUnit_customType_label() {
        return holder.format("xUnit.customType.label");
    }

    /**
     * Custom Tool
     * 
     */
    public static Localizable _xUnit_customType_label() {
        return new Localizable(holder, "xUnit.customType.label");
    }

    /**
     * UnitTest
     * 
     */
    public static String xUnit_unittestType_label() {
        return holder.format("xUnit.unittestType.label");
    }

    /**
     * UnitTest
     * 
     */
    public static Localizable _xUnit_unittestType_label() {
        return new Localizable(holder, "xUnit.unittestType.label");
    }

    /**
     * Boost Test Library
     * 
     */
    public static String xUnit_boosttestType_label() {
        return holder.format("xUnit.boosttestType.label");
    }

    /**
     * Boost Test Library
     * 
     */
    public static Localizable _xUnit_boosttestType_label() {
        return new Localizable(holder, "xUnit.boosttestType.label");
    }

}

==> xunit-0.5-sources.jar: com/thalesgroup/hudson/plugins/xunit/types/Messages.java <==
// CHECKSTYLE:OFF

package com.thalesgroup.hudson.plugins.xunit.types;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * NUnit
     * 
     */
    public static String xUnit_nunitType_label() {
        return holder.format("xUnit.nunitType.label");
    }

    /**
     * NUnit
     * 
     */
    public static Localizable _xUnit_nunitType_label() {
        return new Localizable(holder, "xUnit.nunitType.label");
    }

    /**
     * UnitTest
     * 
     */
    public static String xUnit_unittestType_label() {
        return holder.format("xUnit.unittestType.label");
    }

    /**
     * UnitTest
     * 
     */
    public static Localizable _xUnit_unittestType_label() {
        return new Localizable(holder, "xUnit.unittestType.label");
    }

    /**
     * Free Pascal JUnit
     * 
     */
    public static String xUnit_fpcunitType_label() {
        return holder.format("xUnit.fpcunitType.label");
    }

    /**
     * Free Pascal JUnit
     * 
     */
    public static Localizable _xUnit_fpcunitType_label() {
        return new Localizable(holder, "xUnit.fpcunitType.label");
    }

    /**
     * MSTest
     * 
     */
    public static String xUnit_mstestType_label() {
        return holder.format("xUnit.mstestType.label");
    }

    /**
     * MSTest
     * 
     */
    public static Localizable _xUnit_mstestType_label() {
        return new Localizable(holder, "xUnit.mstestType.label");
    }

    /**
     * PHPUnit
     * 
     */
    public static String xUnit_phpunitType_label() {
        return holder.format("xUnit.phpunitType.label");
    }

    /**
     * PHPUnit
     * 
     */
    public static Localizable _xUnit_phpunitType_label() {
        return new Localizable(holder, "xUnit.phpunitType.label");
    }

    /**
     * CppUnit
     * 
     */
    public static String xUnit_cppUnitType_label() {
        return holder.format("xUnit.cppUnitType.label");
    }

    /**
     * CppUnit
     * 
     */
    public static Localizable _xUnit_cppUnitType_label() {
        return new Localizable(holder, "xUnit.cppUnitType.label");
    }

    /**
     * Gallio
     * 
     */
    public static String xUnit_gallioType_label() {
        return holder.format("xUnit.gallioType.label");
    }

    /**
     * Gallio
     * 
     */
    public static Localizable _xUnit_gallioType_label() {
        return new Localizable(holder, "xUnit.gallioType.label");
    }

    /**
     * Custom Tool
     * 
     */
    public static String xUnit_customType_label() {
        return holder.format("xUnit.customType.label");
    }

    /**
     * Custom Tool
     * 
     */
    public static Localizable _xUnit_customType_label() {
        return new Localizable(holder, "xUnit.customType.label");
    }

    /**
     * Boost Test Library
     * 
     */
    public static String xUnit_boosttestType_label() {
        return holder.format("xUnit.boosttestType.label");
    }

    /**
     * Boost Test Library
     * 
     */
    public static Localizable _xUnit_boosttestType_label() {
        return new Localizable(holder, "xUnit.boosttestType.label");
    }

}
